@@ -43,12 +43,14 @@
 #include <geos/triangulate/quadedge/QuadEdge.h>
 #include <geos/triangulate/quadedge/QuadEdgeQuartet.h>
 #include <geos/triangulate/quadedge/Vertex.h>
+#include <geos/operation/overlayng/Edge.h>
+#include <geos/operation/overlayng/EdgeSourceInfo.h>
+#include <geos/operation/overlayng/OverlayLabel.h>
 
-using namespace std;
 using namespace geos;
 
 #define check(x) \
-	{ cout << "Size of " << #x << " is " << sizeof(x) << endl; }
+	{ std::cout << "Size of " << #x << " is " << sizeof(x) << std::endl; }
 
 int
 main()
@@ -77,6 +79,9 @@ main()
     check(triangulate::quadedge::QuadEdge);
     check(triangulate::quadedge::QuadEdgeQuartet);
     check(triangulate::quadedge::Vertex);
-    check(int64);
+    check(operation::overlayng::Edge);
+    check(operation::overlayng::EdgeSourceInfo);
+    check(operation::overlayng::OverlayLabel);
+    check(int64_t);
 }
 
