@@ -61,24 +61,6 @@ namespace buffer { // geos.operation.buffer
 static Profiler* profiler = Profiler::instance();
 #endif
 
-#if 0
-double
-OLDprecisionScaleFactor(const Geometry* g,
-                        double distance, int maxPrecisionDigits)
-{
-    const Envelope* env = g->getEnvelopeInternal();
-    double envSize = std::max(env->getHeight(), env->getWidth());
-    double expandByDistance = distance > 0.0 ? distance : 0.0;
-    double bufEnvSize = envSize + 2 * expandByDistance;
-    // the smallest power of 10 greater than the buffer envelope
-    int bufEnvLog10 = (int)(std::log(bufEnvSize) / std::log(10.0) + 1.0);
-    int minUnitLog10 = bufEnvLog10 - maxPrecisionDigits;
-    // scale factor is inverse of min Unit size, so flip sign of exponent
-    double scaleFactor = std::pow(10.0, -minUnitLog10);
-    return scaleFactor;
-}
-#endif
-
 /*private*/
 double
 BufferOp::precisionScaleFactor(const Geometry* g,
@@ -104,7 +86,7 @@ BufferOp::precisionScaleFactor(const Geometry* g,
 }
 
 /*public static*/
-Geometry*
+std::unique_ptr<Geometry>
 BufferOp::bufferOp(const Geometry* g, double distance,
                    int quadrantSegments,
                    int nEndCapStyle)
@@ -116,12 +98,12 @@ BufferOp::bufferOp(const Geometry* g, double distance,
 }
 
 /*public*/
-Geometry*
+std::unique_ptr<Geometry>
 BufferOp::getResultGeometry(double nDistance)
 {
     distance = nDistance;
     computeGeometry();
-    return resultGeometry;
+    return std::unique_ptr<Geometry>(resultGeometry.release());
 }
 
 /*private*/
@@ -174,8 +156,6 @@ BufferOp::bufferReducedPrecision()
         }
 
         if(resultGeometry != nullptr) {
-            // debug
-            //if ( saveException ) std::cerr<<saveException->toString()<<std::endl;
             return;
         }
     }
@@ -188,8 +168,8 @@ void
 BufferOp::bufferOriginalPrecision()
 {
     BufferBuilder bufBuilder(bufParams);
+    bufBuilder.setInvertOrientation(isInvertOrientation);
 
-    //std::cerr<<"computing with original precision"<<std::endl;
     try {
         resultGeometry = bufBuilder.buffer(argGeom, distance);
     }
@@ -197,10 +177,7 @@ BufferOp::bufferOriginalPrecision()
         // don't propagate the exception - it will be detected by
         // fact that resultGeometry is null
         saveException = ex;
-
-        //std::cerr<<ex->toString()<<std::endl;
     }
-    //std::cerr<<"done"<<std::endl;
 }
 
 void
@@ -242,6 +219,7 @@ BufferOp::bufferFixedPrecision(const PrecisionModel& fixedPM)
     BufferBuilder bufBuilder(bufParams);
     bufBuilder.setWorkingPrecisionModel(&fixedPM);
     bufBuilder.setNoder(&noder);
+    bufBuilder.setInvertOrientation(isInvertOrientation);
     resultGeometry = bufBuilder.buffer(argGeom, distance);
 
 #else
@@ -252,6 +230,7 @@ BufferOp::bufferFixedPrecision(const PrecisionModel& fixedPM)
     BufferBuilder bufBuilder(bufParams);
     bufBuilder.setWorkingPrecisionModel(&fixedPM);
     bufBuilder.setNoder(&noder);
+    bufBuilder.setInvertOrientation(isInvertOrientation);
 
     // Snap by reducing the precision of the input geometry
     //
@@ -281,6 +260,61 @@ BufferOp::bufferFixedPrecision(const PrecisionModel& fixedPM)
 #endif
 }
 
+/* public static */
+std::unique_ptr<Geometry>
+BufferOp::bufferByZero(const Geometry* geom, bool isBothOrientations)
+{
+    //--- compute buffer using maximum signed-area orientation
+    std::unique_ptr<Geometry> buf0(geom->buffer(0));
+    if (!isBothOrientations)
+        return buf0;
+
+    //-- compute buffer using minimum signed-area orientation
+    BufferOp op(geom);
+    op.isInvertOrientation = true;
+    std::unique_ptr<Geometry> buf0Inv(op.getResultGeometry(0));
+
+    //-- the buffer results should be non-adjacent, so combining is safe
+    if (buf0->isEmpty()) return buf0Inv;
+    if (buf0Inv->isEmpty()) return buf0;
+
+    std::vector<std::unique_ptr<Geometry>> polys;
+    extractPolygons(buf0.release(), polys);
+    extractPolygons(buf0Inv.release(), polys);
+    if (polys.size() == 1) {
+        std::unique_ptr<Geometry> poly(polys.at(0).release());
+        return poly;
+    }
+    if (polys.size() == 0) {
+        return geom->getFactory()->createMultiPolygon();
+    }
+    return geom->getFactory()->createMultiPolygon(std::move(polys));
+}
+
+/* private static */
+void
+BufferOp::extractPolygons(Geometry* geom, std::vector<std::unique_ptr<geom::Geometry>>& polys)
+{
+    Polygon* p = dynamic_cast<Polygon*>(geom);
+    if (p) {
+        polys.emplace_back(p);
+        return;
+    }
+    MultiPolygon* mp = dynamic_cast<MultiPolygon*>(geom);
+    if (mp) {
+        std::vector<std::unique_ptr<Geometry>> subPolys = mp->releaseGeometries();
+        for (auto& subPoly : subPolys) {
+            polys.emplace_back(subPoly.release());
+        }
+        delete mp;
+        return;
+    }
+    return;
+}
+
+
+
+
 } // namespace geos.operation.buffer
 } // namespace geos.operation
 } // namespace geos
