@@ -10,31 +10,15 @@
 #include <cstdlib>
 #include <memory>
 
+#include "capi_test_utils.h"
+
 namespace tut {
 //
 // Test Group
 //
 
 // Common data used in test cases.
-struct test_capigeosclipbyrect_data {
-    GEOSGeometry* geom1_;
-    GEOSGeometry* geom2_;
-    GEOSGeometry* geom3_;
-    GEOSWKTWriter* w_;
-
-    static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
+struct test_capigeosclipbyrect_data : public capitest::utility {
     void
     isEqual(GEOSGeom g, const char* exp_wkt)
     {
@@ -42,7 +26,7 @@ struct test_capigeosclipbyrect_data {
         bool eq = GEOSEquals(geom3_, g) != 0;
         if(! eq) {
             std::printf("EXP: %s\n", exp_wkt);
-            char* obt_wkt = GEOSWKTWriter_write(w_, g);
+            char* obt_wkt = GEOSWKTWriter_write(wktw_, g);
             std::printf("OBT: %s\n", obt_wkt);
             free(obt_wkt);
         }
@@ -50,26 +34,10 @@ struct test_capigeosclipbyrect_data {
     }
 
     test_capigeosclipbyrect_data()
-        : geom1_(nullptr), geom2_(nullptr), geom3_(nullptr), w_(nullptr)
     {
-        initGEOS(notice, notice);
-        w_ = GEOSWKTWriter_create();
-        GEOSWKTWriter_setTrim(w_, 1);
-        GEOSWKTWriter_setRoundingPrecision(w_, 8);
+        GEOSWKTWriter_setTrim(wktw_, 1);
+        GEOSWKTWriter_setRoundingPrecision(wktw_, 8);
     }
-
-    ~test_capigeosclipbyrect_data()
-    {
-        GEOSGeom_destroy(geom1_);
-        GEOSGeom_destroy(geom2_);
-        GEOSGeom_destroy(geom3_);
-        GEOSWKTWriter_destroy(w_);
-        geom1_ = nullptr;
-        geom2_ = nullptr;
-        geom3_ = nullptr;
-        finishGEOS();
-    }
-
 };
 
 typedef test_group<test_capigeosclipbyrect_data> group;
@@ -200,5 +168,42 @@ template<> template<> void object::test<13>
     isEqual(geom2_, "POLYGON ((5 5, 5 15, 10 15, 10 10, 15 10, 15 5, 5 5))");
 }
 
+/// Clipping invalid polygon
+template<> template<> void object::test<14>
+()
+{
+    const char* wkt = "POLYGON((1410 2055, 1410 2056, 1410 2057, 1410 2055))";
+    geom1_ = GEOSGeomFromWKT(wkt);
+    geom2_ = GEOSClipByRect(geom1_, -8, -8, 2056, 2056);
+    if (geom2_ != nullptr) {
+        char* obt_wkt = GEOSWKTWriter_write(wktw_, geom2_);
+        std::printf("OBT: %s\n", obt_wkt);
+    }
+    ensure(nullptr == geom2_);
+}
+
+// Polygon fully covering rectangle
+// https://trac.osgeo.org/postgis/ticket/4904
+template<> template<> void object::test<15>
+()
+{
+    //  POLYGON((0 0,10 0,10 10,0 10))
+    //  Clip by ST_MakeEnvelope(2,2,5,5)
+    GEOSCoordSequence *cs = GEOSCoordSeq_create(5, 2);
+    GEOSCoordSeq_setXY(cs, 0,  0,  0);
+    GEOSCoordSeq_setXY(cs, 1, 10,  0);
+    GEOSCoordSeq_setXY(cs, 2, 10, 10);
+    GEOSCoordSeq_setXY(cs, 3,  0, 10);
+    GEOSCoordSeq_setXY(cs, 4,  0,  0);
+    GEOSGeometry *shell = GEOSGeom_createLinearRing(cs);
+    geom1_ = GEOSGeom_createPolygon(shell, NULL, 0);
+
+
+    geom2_ = GEOSClipByRect(geom1_, 2, 2, 5, 5);
+    isEqual(geom2_, "POLYGON ((2 2, 2 5, 5 5, 5 2, 2 2))");
+}
+
+
+
 } // namespace tut
 
