@@ -9,44 +9,15 @@
 #include <cstdio>
 #include <cstdlib>
 
+#include "capi_test_utils.h"
+
 namespace tut {
 //
 // Test Group
 //
 
 // Common data used in test cases.
-struct test_capigeosconvexhull_data {
-    GEOSGeometry* input_;
-    GEOSGeometry* expected_;
-
-    static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
-    test_capigeosconvexhull_data()
-        : input_(nullptr), expected_(nullptr)
-    {
-        initGEOS(notice, notice);
-    }
-
-    ~test_capigeosconvexhull_data()
-    {
-        GEOSGeom_destroy(input_);
-        GEOSGeom_destroy(expected_);
-        input_ = nullptr;
-        expected_ = nullptr;
-        finishGEOS();
-    }
-
+struct test_capigeosconvexhull_data : public capitest::utility {
 };
 
 typedef test_group<test_capigeosconvexhull_data> group;
