@@ -4,51 +4,22 @@
 #include <tut/tut.hpp>
 // geos
 #include <geos_c.h>
+#include <geos/constants.h>
 // std
 #include <cstdarg>
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
 
+#include "capi_test_utils.h"
+
 namespace tut {
 //
 // Test Group
 //
 
 // Common data used in test cases.
-struct test_capigeosintersects_data {
-    GEOSGeometry* geom1_;
-    GEOSGeometry* geom2_;
-
-    static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
-    test_capigeosintersects_data()
-        : geom1_(nullptr), geom2_(nullptr)
-    {
-        initGEOS(notice, notice);
-    }
-
-    ~test_capigeosintersects_data()
-    {
-        GEOSGeom_destroy(geom1_);
-        GEOSGeom_destroy(geom2_);
-        geom1_ = nullptr;
-        geom2_ = nullptr;
-        finishGEOS();
-    }
-
-};
+struct test_capigeosintersects_data : public capitest::utility {};
 
 typedef test_group<test_capigeosintersects_data> group;
 typedef group::object object;
@@ -127,7 +98,7 @@ void object::test<4>
 {
     GEOSCoordSequence* cs = GEOSCoordSeq_create(5, 2);
 
-    constexpr double nan = std::numeric_limits<double>::quiet_NaN();
+    constexpr double nan = geos::DoubleNotANumber;
     GEOSCoordSeq_setX(cs, 0, 1);
     GEOSCoordSeq_setY(cs, 0, 1);
     for(unsigned int i = 1; i < 4; ++i) {
