@@ -3,42 +3,22 @@
 #include <tut/tut.hpp>
 // geos
 #include <geos_c.h>
+#include <geos/constants.h>
 // std
 #include <cstdarg>
 #include <cstdio>
 #include <cstdlib>
 
+#include "capi_test_utils.h"
+
 namespace tut {
 //
 // Test Group
 //
 
 // Common data used in test cases.
-struct test_capigeosminimumclearance_data {
+struct test_capigeosminimumclearance_data : public capitest::utility {
     static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
-    test_capigeosminimumclearance_data()
-    {
-        initGEOS(notice, notice);
-    }
-
-    ~test_capigeosminimumclearance_data()
-    {
-        finishGEOS();
-    }
-
-    void
     testClearance(const std::string& wkx_input,
                   const std::string& wkx_expected,
                   double clearance)
@@ -64,7 +44,7 @@ struct test_capigeosminimumclearance_data {
         int error = GEOSMinimumClearance(input, &d);
 
         ensure(!error);
-        if(clearance == std::numeric_limits<double>::infinity()) {
+        if(clearance == geos::DoubleInfinity) {
             ensure(d == clearance);
         }
         else {
@@ -97,7 +77,7 @@ void object::test<1>
 {
     testClearance("MULTIPOINT ((100 100), (100 100))",
                   "LINESTRING EMPTY",
-                  std::numeric_limits<double>::infinity());
+                  geos::DoubleInfinity);
 }
 
 template<>
@@ -137,7 +117,7 @@ void object::test<5>
 {
     testClearance("POLYGON EMPTY",
                   "LINESTRING EMPTY",
-                  std::numeric_limits<double>::infinity());
+                  geos::DoubleInfinity);
 }
 
 } // namespace tut
