@@ -8,49 +8,20 @@
 #include <cstdio>
 #include <cstdlib>
 
+#include "capi_test_utils.h"
+
 namespace tut {
 //
 // Test Group
 //
 
 // Common data used in test cases.
-struct test_capigeosminimumwidth_data {
-    GEOSGeometry* input_;
-    GEOSWKTWriter* wktw_;
-    char* wkt_;
-
-    static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
+struct test_capigeosminimumwidth_data : public capitest::utility {
     test_capigeosminimumwidth_data()
-        : input_(nullptr), wkt_(nullptr)
     {
-        initGEOS(notice, notice);
-        wktw_ = GEOSWKTWriter_create();
         GEOSWKTWriter_setTrim(wktw_, 1);
         GEOSWKTWriter_setRoundingPrecision(wktw_, 8);
     }
-
-    ~test_capigeosminimumwidth_data()
-    {
-        GEOSGeom_destroy(input_);
-        input_ = nullptr;
-        GEOSWKTWriter_destroy(wktw_);
-        GEOSFree(wkt_);
-        wkt_ = nullptr;
-        finishGEOS();
-    }
-
 };
 
 typedef test_group<test_capigeosminimumwidth_data> group;
