@@ -10,52 +10,18 @@
 #include <cstdlib>
 #include <cstring>
 
+#include "capi_test_utils.h"
+
 namespace tut {
 //
 // Test Group
 //
 
 // Common data used in test cases.
-struct test_capioffsetcurve_data {
-    GEOSGeometry* geom1_;
-    GEOSGeometry* geom2_;
-    GEOSWKTWriter* wktw_;
-    char* wkt_;
-    double area_;
-
-    static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
-    test_capioffsetcurve_data()
-        : geom1_(nullptr), geom2_(nullptr), wkt_(nullptr)
-    {
-        initGEOS(notice, notice);
-        wktw_ = GEOSWKTWriter_create();
+struct test_capioffsetcurve_data : public capitest::utility {
+    test_capioffsetcurve_data() {
         GEOSWKTWriter_setTrim(wktw_, 1);
     }
-
-    ~test_capioffsetcurve_data()
-    {
-        GEOSGeom_destroy(geom1_);
-        GEOSGeom_destroy(geom2_);
-        GEOSWKTWriter_destroy(wktw_);
-        GEOSFree(wkt_);
-        geom1_ = nullptr;
-        geom2_ = nullptr;
-        wkt_ = nullptr;
-        finishGEOS();
-    }
-
 };
 
 typedef test_group<test_capioffsetcurve_data> group;
