@@ -11,53 +11,20 @@
 #include <cstdlib>
 #include <cstring>
 
+#include "capi_test_utils.h"
+
 namespace tut {
 //
 // Test Group
 //
 
 // Common data used in test cases.
-struct test_capipointonsurface_data {
-    GEOSGeometry* geom1_;
-    GEOSGeometry* geom2_;
-    GEOSWKTWriter* wktw_;
-    char* wkt_;
-    double area_;
-
-    static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
+struct test_capipointonsurface_data : public capitest::utility {
     test_capipointonsurface_data()
-        : geom1_(nullptr), geom2_(nullptr), wkt_(nullptr)
     {
-        initGEOS(notice, notice);
-        wktw_ = GEOSWKTWriter_create();
         GEOSWKTWriter_setTrim(wktw_, 1);
-        GEOSWKTWriter_setRoundingPrecision(wktw_, 8);
+        GEOSWKTWriter_setRoundingPrecision(wktw_, 4);
     }
-
-    ~test_capipointonsurface_data()
-    {
-        GEOSGeom_destroy(geom1_);
-        GEOSGeom_destroy(geom2_);
-        GEOSWKTWriter_destroy(wktw_);
-        GEOSFree(wkt_);
-        geom1_ = nullptr;
-        geom2_ = nullptr;
-        wkt_ = nullptr;
-        finishGEOS();
-    }
-
 };
 
 typedef test_group<test_capipointonsurface_data> group;
@@ -150,7 +117,7 @@ void object::test<4>
 
     wkt_ = GEOSWKTWriter_write(wktw_, geom2_);
 
-    ensure_equals(std::string(wkt_), std::string("POINT (56.528667 25.210167)"));
+    ensure_equals(std::string(wkt_), std::string("POINT (56.5287 25.2102)"));
 
 }
 
@@ -213,7 +180,7 @@ void object::test<7>
     ensure(nullptr != geom2_);
 
     wkt_ = GEOSWKTWriter_write(wktw_, geom2_);
-    ensure_equals(std::string(wkt_), std::string("POINT (182077.08 141881.65)"));
+    ensure_equals(std::string(wkt_), std::string("POINT (182077.0753 141881.6525)"));
 }
 
 template<>
@@ -234,7 +201,7 @@ void object::test<8>
     ensure(nullptr != geom2_);
 
     wkt_ = GEOSWKTWriter_write(wktw_, geom2_);
-    ensure_equals(std::string(wkt_), std::string("POINT (182476.76 141880.71)"));
+    ensure_equals(std::string(wkt_), std::string("POINT (182476.7586 141880.7091)"));
 }
 
 template<>
@@ -255,7 +222,7 @@ void object::test<9>
     ensure(nullptr != geom2_);
 
     wkt_ = GEOSWKTWriter_write(wktw_, geom2_);
-    ensure_equals(std::string(wkt_), std::string("POINT (182755.89 141812.88)"));
+    ensure_equals(std::string(wkt_), std::string("POINT (182755.892 141812.8789)"));
 }
 
 } // namespace tut
