@@ -15,6 +15,7 @@
 #include <geos/io/WKTReader.h>
 #include <geos/util/GEOSException.h>
 #include <geos/util/IllegalArgumentException.h>
+#include <geos/constants.h>
 // std
 #include <string>
 #include <cmath>
@@ -90,7 +91,7 @@ void object::test<2>
     using geos::geom::Coordinate;
 
     // Non-empty sequence of coordinates
-    const size_t size3 = 3;
+    const std::size_t size3 = 3;
 
     CoordArrayPtr pseq = new geos::geom::CoordinateArraySequence();
     ensure("sequence is null pointer.", pseq != nullptr);
@@ -170,7 +171,7 @@ void object::test<4>
     using geos::geom::Coordinate;
 
     // Non-empty sequence of coordinates
-    const size_t size = 3;
+    const std::size_t size = 3;
 
     CoordArrayPtr pseq = new geos::geom::CoordinateArraySequence();
     ensure("sequence is null pointer.", pseq != nullptr);
@@ -430,7 +431,7 @@ template<>
 void object::test<22>
 ()
 {
-    const size_t size = 4;
+    const std::size_t size = 4;
     auto geo = reader_.read("LINESTRING (0 0, 5 5, 10 5, 10 10)");
     ensure(geo != nullptr);
 
@@ -527,5 +528,51 @@ void object::test<29>
     ensure(c != nullptr);
 }
 
+// releaseCoordinates
+template<>
+template<>
+void object::test<30>()
+{
+    auto ls = reader_.read<geos::geom::LineString>("LINESTRING (0 0, 10 10)");
+    auto env = ls->getEnvelopeInternal();
+    ensure_equals(*env, geos::geom::Envelope(0,10, 0, 10));
+
+    auto cs = ls->releaseCoordinates();
+    ensure_equals(cs->getSize(), 2u);
+}
+
+// Test of LinearRing constructor with a NaN coordinate
+template<>
+template<>
+void object::test<31>
+()
+{
+    using geos::geom::Coordinate;
+
+    // Non-empty sequence of coordinates
+    const std::size_t size3 = 3;
+
+    CoordArrayPtr pseq = new geos::geom::CoordinateArraySequence();
+    ensure("sequence is null pointer.", pseq != nullptr);
+
+    pseq->add(Coordinate(0, geos::DoubleNotANumber));
+    pseq->add(Coordinate(5, 5));
+    pseq->add(Coordinate(0, geos::DoubleNotANumber));
+    ensure_equals(pseq->size(), size3);
+
+    try {
+        // Create non-empty LineString instance
+        auto lr(factory_->createLinearRing(pseq));
+        ensure(!lr->isEmpty());
+        fail("IllegalArgumentException expected.");
+    }
+    catch(geos::util::IllegalArgumentException const& e) {
+        const char* msg = e.what(); // OK
+        ensure(msg != nullptr);
+    }
+
+}
+
+
 } // namespace tut
 
