@@ -89,11 +89,11 @@ struct test_facetdistanceop_data {
 
 
     std::unique_ptr<geos::geom::LineString>
-    makeSinCircle(size_t nvertices, double radius, double amplitude)
+    makeSinCircle(std::size_t nvertices, double radius, double amplitude)
     {
         geos::geom::CoordinateArraySequence cs;
         std::vector<geos::geom::Coordinate> coords;
-        for (size_t i = 0; i < nvertices; i++) {
+        for (std::size_t i = 0; i < nvertices; i++) {
             geos::geom::Coordinate c;
             double angle = (double)i*360.0/(double)nvertices;
             angle2sincircle(angle, radius, amplitude, &c.x, &c.y);
@@ -270,8 +270,8 @@ template<>
 void object::test<10>
 ()
 {
-    int npoints = 1000; // vertices in sinstar test shape
-    int ncells = 100; // number of colums/rows in test grid square
+    std::size_t npoints = 1000; // vertices in sinstar test shape
+    int ncells = 100; // number of columns/rows in test grid square
 
     double radius = 100.0;
     double amplitude = 0.3; // how far the sin deviates from perfect circle (0.0)
@@ -309,7 +309,7 @@ void object::test<10>
                                          "TestBoth"};
 
     bool perfTest = false;
-    std::vector<int> m = {TestBoth};
+    std::vector<size_t> m = {TestBoth};
     if (perfTest) {
         m.push_back(TestIndexedFacetDistance);
         m.push_back(TestGeometryDistance);
@@ -318,7 +318,7 @@ void object::test<10>
     for (auto it = m.begin() ; it != m.end(); ++it)
     {
         prof.start(profiles[*it]);
-        for (size_t j = 0; j < pts.size(); j++) {
+        for (std::size_t j = 0; j < pts.size(); j++) {
             double dist_ifd = 0.0, dist_geom = 0.0;
             if (*it == TestIndexedFacetDistance || *it == TestBoth)
                 dist_ifd = ifd.distance(pts[j].get());
@@ -351,16 +351,29 @@ void object::test<11>
     std::string wkt1("POINT(150 150)");
     GeomPtr g0(_wktreader.read(wkt0));
     GeomPtr g1(_wktreader.read(wkt1));
-    IndexedFacetDistance ifd(g0.get());
+    IndexedFacetDistance ifd0(g0.get());
+    IndexedFacetDistance ifd1(g1.get());
 
     try {
-        ifd.distance(g1.get());
+        ifd0.distance(g1.get());
         fail("IndexedFacedDistance::distance did not throw on empty input");
     }
     catch (const GEOSException&) { }
 
     try {
-        ifd.nearestPoints(g1.get());
+        ifd0.nearestPoints(g1.get());
+        fail("IndexedFacedDistance::nearestPoints did not throw on empty input");
+    }
+    catch (const GEOSException&) { }
+
+    try {
+        ifd1.distance(g0.get());
+        fail("IndexedFacedDistance::distance did not throw on empty input");
+    }
+    catch (const GEOSException&) { }
+
+    try {
+        ifd1.nearestPoints(g0.get());
         fail("IndexedFacedDistance::nearestPoints did not throw on empty input");
     }
     catch (const GEOSException&) { }
